@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.5
+# Version: 0.5.1
 # File   : AdvancedContent.module.php
 # Purpose: initial module class. this is the interface to the Module API
 # License: GPL
@@ -42,7 +42,7 @@ class AdvancedContent extends CMSModule {
 	}
 	
 	function GetVersion() {
-		return '0.5';
+		return '0.5.1';
 	}
 	
 	function GetHelp() {
