@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.5
+# Version: 0.5.1
 # File   : action.default.php
 #          This file is a modification of the default plugin {content}
 # Purpose: performs the default frontend action if {AdvancedContent} is used.
@@ -256,13 +256,13 @@ if (isset($pageinfo) && $pageinfo !== FALSE && isset($pageinfo->content_id) )
 			$text    = ucfirst(strtolower($block));
 			
 			if( isset($params['name']) )    $name    = ' name="'.$params['name'].'"';
-			if( isset($params['class']) )   $class   = ' class="'.$params['class'];
-			if( isset($params['id']) )      $elmId   = ' id="'.$params['id'];
-			if( isset($params['alt']) )     $alt     = ' alt="'.$params['alt'];
-			if( isset($params['width']) )   $width   = ' width="'.$params['width'];
-			if( isset($params['height']) )  $height  = ' height="'.$params['height'];
-			if( isset($params['title']) )   $title   = ' title="'.$params['title'];
-			if( isset($params['text']) )    $text    = $params['text'];
+			if( isset($params['class']) )   $class   = ' class="'.$params['class'].'"';
+			if( isset($params['id']) )      $elmId   = ' id="'.$params['id'].'"';
+			if( isset($params['alt']) )     $alt     = ' alt="'.$params['alt'].'"';
+			if( isset($params['width']) )   $width   = ' width="'.$params['width'].'"';
+			if( isset($params['height']) )  $height  = ' height="'.$params['height'].'"';
+			if( isset($params['title']) )   $title   = ' title="'.$params['title'].'"';
+			if( isset($params['text']) )    $text    = $params['text']
 			if( isset($params['urlonly']) && $this->IsTrue($params['urlonly']))
 				$urlonly = true;
 			
