@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.5
+# Version: 0.5.1
 # File   : contenttype.Content2.php
 #          This file is a modification of the default content type "Content"
 # Purpose: the content object
@@ -44,11 +44,6 @@ class Content2 extends CMSModuleContentType {
 	 * @access private
 	 * @var array
 	 */
-    var $blockTabs;
-	/**
-	 * @access private
-	 * @var array
-	 */
 	var $userGroups;
 	/**
 	 * @access private
@@ -257,7 +252,7 @@ class Content2 extends CMSModuleContentType {
 		#	$errors[] = lang('nofieldgiven', array(lang('content')));
 		#	$result   = false;
 		#}
-		if ($this->GetPropertyValue('use_expire_date') == '1' && $this->GetPropertyValue('end_date') <= $this->GetPropertyValue('start_date')) {
+		if ( check_permission(get_userid(), 'Manage AdvancedContent Options') && $this->GetPropertyValue('use_expire_date') == '1' && $this->GetPropertyValue('end_date') <= $this->GetPropertyValue('start_date')) {
 			global $gCms;
 			$AdvancedContent =& $gCms->modules['AdvancedContent']['object'];
 			$errors[] = $AdvancedContent->lang('error_expiredate');
