@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.5
+# Version: 0.5.1
 # File   : function.displayContentBlocks.php
 #          This file is included in ../contenttype.Content2.php in function
 #          EditAsArray()
@@ -46,7 +46,7 @@ foreach($this->_contentBlocks as $blockInfo) {
 			$blockTabs[] = $blockInfo['block_tab'];
 		
 		# MLE support
-		if($this->mle && !$this->blockLang != '' && $blockInfo['block_id'] != 'content' . $this->blockLang)
+		if($this->mle && $this->blockLang != '' && $blockInfo['block_id'] != 'content' . $this->blockLang)
 			$data = $this->GetPropertyValue($blockInfo['block_id'] . $this->blockLang);
 		else #---
 			$data = $this->GetPropertyValue($blockInfo['block_id']);
@@ -83,7 +83,7 @@ foreach($this->_contentBlocks as $blockInfo) {
 		if($blockInfo['translate_labels'])
 			$this->_contentBlocks[$blockInfo['block_id']]['label'] = $AdvancedContent->lang($blockInfo['label']);
 		
-		$blockDisplay = $AdvancedContent->GetElmDisplay('block',$this->mId, $blockInfo['block_id']);
+		$blockDisplay = $AdvancedContent->GetElmDisplay('block',$this->mId, $blockInfo['block_id'], !$blockInfo['collapse']);
 		$this->_contentBlocks[$blockInfo['block_id']]['display']  = $blockDisplay;
 		$this->_contentBlocks[$blockInfo['block_id']]['pref_url'] = str_replace('&amp;','&',
 			$AdvancedContent->CreateLink('m1_', 'savePrefs', '', $this->lang('toggle_block'), 
@@ -289,7 +289,7 @@ foreach($this->_contentBlocks as $blockInfo) {
 				
 				$items = array();
 				if($blockInfo['items'] != '') {
-					foreach($this->CleanArray(explode($blockInfo['delimiter'], $blockInfo['items'])) as $key => $val) {
+					foreach(explode($blockInfo['delimiter'], $blockInfo['items']) as $key => $val) {
 						$items[$key]['label'] = trim($val);
 						if($blockInfo['translate_labels'])
 							$items[$key]['label'] = $AdvancedContent->lang($items[$key]['label']);
@@ -299,7 +299,7 @@ foreach($this->_contentBlocks as $blockInfo) {
 					}
 				}
 				if($blockInfo['values'] != '') {
-					foreach($this->CleanArray(explode($blockInfo['delimiter'], $blockInfo['values'])) as $key => $val) {
+					foreach(explode($blockInfo['delimiter'], $blockInfo['values']) as $key => $val) {
 						$items[$key]['value'] = trim($val);
 						if($blockInfo['translate_values'])
 							$items[$key]['value'] = $AdvancedContent->lang($items[$key]['value']);
@@ -326,12 +326,12 @@ foreach($this->_contentBlocks as $blockInfo) {
 			case 'select_multiple':
 				
 				$selItems = array();
-				foreach($this->CleanArray(explode($blockInfo['delimiter'], $data)) as $key => $val) {
+				foreach(explode($blockInfo['delimiter'], $data) as $key => $val) {
 					$selItems[$key] = trim($val);
 				}
 				$items = array();
 				if($blockInfo['items'] != '') {
-					foreach($this->CleanArray(explode($blockInfo['delimiter'], $blockInfo['items'])) as $key => $val) {
+					foreach(explode($blockInfo['delimiter'], $blockInfo['items']) as $key => $val) {
 						$items[$key]['label']    = trim($val);
 						if($blockInfo['translate_labels'])
 							$items[$key]['label'] = $AdvancedContent->lang($items[$key]['label']);
@@ -341,7 +341,7 @@ foreach($this->_contentBlocks as $blockInfo) {
 					}
 				}
 				if($blockInfo['values'] != '') {
-					foreach($this->CleanArray(explode($blockInfo['delimiter'], $blockInfo['values'])) as $key => $val) {
+					foreach(explode($blockInfo['delimiter'], $blockInfo['values']) as $key => $val) {
 						$items[$key]['value']    = trim($val);
 						if($blockInfo['translate_values'])
 							$items[$key]['value'] = $AdvancedContent->lang($items[$key]['value']);
