@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.5
+# Version: 0.5.1
 # File   : function.fillParams.php
 #          This file is included in ../contenttype.Content2.php in function
 #          FillParams()
@@ -41,7 +41,7 @@ if(!empty($params)) {
 		if(isset($params['parent_id']))
 			$parentId = $params['parent_id'];
 		
-		if(isset($params['feu_access'])) {
+		if(isset($params['feu_access']) && check_permission(get_userid(), 'Manage AdvancedContent Options')) {
 			
 			if(!is_array($params['feu_access']))
 				$feuAccess = array();
@@ -94,7 +94,7 @@ if(!empty($params)) {
 		
 		// do the content property parameters
 		foreach ($parameters as $oneparam) {
-			if($oneparam == 'start_date' || $oneparam == 'end_date') {
+			if(($oneparam == 'start_date' || $oneparam == 'end_date') && check_permission(get_userid(), 'Manage AdvancedContent Options')) {
 				$_string           = ucfirst(str_replace('_date','',$oneparam));
 				$params[$oneparam] = 0;
 				if(isset($params['AdvancedContent'.$_string.'Time']) && isset($params['AdvancedContent'.$_string.'Date']))
@@ -105,7 +105,7 @@ if(!empty($params)) {
 			}
 		}
 		
-		if(isset($params['start_date']) && isset($params['use_expire_date']) && $params['use_expire_date'] == 1 && $params['start_date'] > time()) {
+		if(check_permission(get_userid(), 'Manage AdvancedContent Options') && isset($params['start_date']) && isset($params['use_expire_date']) && $params['use_expire_date'] == 1 && $params['start_date'] > time()) {
 			$params['active'] = false;
 			$this->mActive    = false;
 		}
