@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.5
+# Version: 0.5.1
 # File   : function.getContentBlocks.php
 #          This file is included in the contenttype.Content2.php in function
 #          get_content_blocks()
@@ -124,6 +124,11 @@ if($template !== false) {
 				continue;
 			}
 			
+			if(isset($this->_contentBlocks[$blockId])) {
+				$this->_contentBlocks[$blockId]['multiple'] = true;
+				continue;
+			}
+			
 			$smarty = false;
 			if(isset($keyval['smarty']) && $this->IsTrue($keyval['smarty'])) {
 				$smarty = true;
@@ -187,10 +192,9 @@ if($template !== false) {
 			if(isset($keyval['description']))
 				$description = trim($keyval['description']);
 			
-			if(isset($this->_contentBlocks[$blockId])) {
-				$this->_contentBlocks[$blockId]['multiple'] = true;
-				continue;
-			}
+			$collapse = false;
+			if(isset($keyval['collapse']) && $this->IsTrue($keyval['collapse']))
+				$collapse = trim($keyval['collapse']);
 			
 			// this will create an invalid block type to print out a 
 			// message when using a basic content property as block name
@@ -218,7 +222,6 @@ if($template !== false) {
 				$this->_contentBlocks[$blockId]['page_tab']         = $pageTab;
 				$this->_contentBlocks[$blockId]['style']            = '';
 				$this->_contentBlocks[$blockId]['label']            = $label;
-				#$this->_contentBlocks[$blockId]['options']          = false;
 				$this->_contentBlocks[$blockId]['allow_none']       = false;
 				$this->_contentBlocks[$blockId]['sortable']         = false;
 				$this->_contentBlocks[$blockId]['save_db']          = false;
@@ -231,6 +234,7 @@ if($template !== false) {
 				$this->_contentBlocks[$blockId]['editor_groups']    = $editorGroups;
 				$this->_contentBlocks[$blockId]['sequence']         = count($this->_contentBlocks);
 				$this->_contentBlocks[$blockId]['default_mode']     = false;
+				$this->_contentBlocks[$blockId]['collapse']         = false;
 				continue;
 			}
 			
@@ -466,11 +470,6 @@ if($template !== false) {
 				else
 					continue; // don't show empty stuff here
 			}
-			else if($blockType == 'block_group') {
-				// ToDo:
-				// groups = groupname(s) (get from db)
-				// multiple_groups (true/false)
-			}
 			
 			$this->_contentBlocks[$blockId]['multiple']         = false;
 			$this->_contentBlocks[$blockId]['smarty']           = $smarty;
@@ -482,7 +481,6 @@ if($template !== false) {
 			$this->_contentBlocks[$blockId]['label']            = $label;
 			$this->_contentBlocks[$blockId]['block_tab']        = $blockTab;
 			$this->_contentBlocks[$blockId]['page_tab']         = $pageTab;
-			#$this->_contentBlocks[$blockId]['options']          = false;
 			$this->_contentBlocks[$blockId]['save_db']          = false;
 			$this->_contentBlocks[$blockId]['sortable']         = false;
 			$this->_contentBlocks[$blockId]['new_block']        = $newBlock;
@@ -494,13 +492,10 @@ if($template !== false) {
 			$this->_contentBlocks[$blockId]['description']      = $description;
 			$this->_contentBlocks[$blockId]['sequence']         = count($this->_contentBlocks);
 			$this->_contentBlocks[$blockId]['default_mode']     = $defaultMode;
-			
+			$this->_contentBlocks[$blockId]['collapse']         = $collapse;
 			$this->AddExtraProperty($blockId);
-			
 		}
-		
 	}
-	
 	// force a load
 	$this->mProperties->Load($this->mId);
 	$this->_contentBlocksLoaded = true;
