@@ -6,7 +6,7 @@
 #          The projects homepage is http://dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp (wishy@cmsmadesimple.org)
 #          The projects homepage is: http://www.cmsmadesimple.org
-# Version: 0.5
+# Version: 0.5.1
 # File   : method.uninstall.php
 # Purpose: uninstalls the module, removes tables, preferences, permissions... 
 # License: GPL
@@ -21,6 +21,8 @@ $sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_AdvancedContent_blockdi
 $dict->ExecuteSQLArray($sqlarray);
 $sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_AdvancedContent_messagedisplay" );
 $dict->ExecuteSQLArray($sqlarray);
+$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_AdvancedContent_groupdisplay" );
+$dict->ExecuteSQLArray($sqlarray);
 
 if($this->GetPreference('uninstall_action') != '') {
 	switch($this->GetPreference('uninstall_action')) {
@@ -76,11 +78,7 @@ if($this->GetPreference('uninstall_action') != '') {
 // remove permissions
 $this->RemovePermission('Manage AdvancedContent');
 $this->RemovePermission('Manage All AdvancedContent Blocks');
-$this->RemovePermission('Approve AdvancedContent');
-$this->RemovePermission('Modify AdvancedContent Block Options');
-$this->RemovePermission('Modify AdvancedContent Block Order');
-$this->RemovePermission('Add AdvancedContent Blocks');
-$this->RemovePermission('Delete AdvancedContent Blocks');
+$this->RemovePermission('Manage AdvancedContent Options');
 
 $this->RemoveEventHandler( 'Core', 'ContentPostRender');
 
