@@ -6,7 +6,7 @@
 #          The projects homepage is http://dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2010 by Ted Kulp (wishy@cmsmadesimple.org)
 #          The projects homepage is: http://www.cmsmadesimple.org
-# Version: 0.5
+# Version: 0.5.1
 # File   : method.upgrade.php
 # Purpose: performs a module upgrade
 # License: GPL
@@ -94,7 +94,8 @@ switch($current_version) {
 		$dict->ExecuteSQLArray($sqlarray);
 		
 		$current_version = '0.3.4';
-		
+	
+	case '0.3.4':
 	case '0.4':
 		// add new table for user prefs
 		$taboptarray = array('mysql' => 'TYPE=MyISAM');
